CREATE TABLE active_sessions (
	sessid char(32) primary key, 
	uid char(25),
	lastused integer unsigned,
	ip char(16)
);

CREATE TABLE membergroup (
        userid int(4) not null,
        groupid int(4) not null
);

CREATE TABLE folders (
        id int(4) not null auto_increment,
        name char(255) not null,
        parent int(4) not null,
        description text not null,
        security char(5) not null,
        groupid int(4) not null,
        creatorid int(4) not null,
        primary key (id)
);

create UNIQUE INDEX folderid_index ON folders (id);

CREATE TABLE files (
        id int(4) not null auto_increment,
        name char(80) not null,
        filename char(255) not null,
        size bigint not null,
        creatorid int(4) not null,
        parent int(4) not null,
        created datetime not null,
        description text not null,
        metadata text not null,
        security int(4) not null,
        groupid int(4) not null,
        smodified datetime not null,
        checked_out int(4) not null default 0,
        major_revision int(4) not null default 0,
        minor_revision int(4) not null default 1,
        url int(4) not null default 0,
        primary key (id)
);
create UNIQUE INDEX fileid_index ON files (id);

CREATE TABLE comment (
        id int(4) not null auto_increment,
        fid int(4) not null,
        userid int(4),
        comment_date datetime not null,
        comment text not null,
        primary key (id)
);

CREATE TABLE news (
        id int(4) not null auto_increment,
        gid int(4) not null,
        news_title char(255) not null,
        news_date datetime not null,
        news text not null,
        news_end_date datetime not null,
        primary key (id)
);

CREATE TABLE filedata (
        id int(4) not null,
        compressed int(4) not null default 0,
        data longblob,
        primary key (id)
);

CREATE TABLE users (
        id int(4) not null auto_increment,
        groupid char(10) not null,
        username char(20) not null,
        name char(50) not null,
        password char(50) not null,
	quota_max int(16) not null,
	quota_current int(16) not null,
        email char(255),
        notify int(4),
        attachfile int(4),
        disabled int(4),
	noprefaccess int(4) default 0,
        language char(15),
	maxsessions int(4) default 0,
        lastlogin datetime not null,
        curlogin datetime not null,
	lastnews int(4) not null,
	newsadmin int(4) not null,
	comment_notify int(4) not null,
	buttonstyle varchar(255),
        primary key (id)
);

CREATE TABLE groups (
        id int(4) not null auto_increment,
        name char(30) not null,
        primary key (id)
);

CREATE TABLE owl_log (
        id int(4) not null auto_increment,
        userid int(4),
	filename char(255),
        parent int(4),
	action char(40),
	details text,
	ip char(16),
	agent char(100),
        logdate datetime not null,
	type char(20),
        primary key (id)
);



CREATE TABLE html (
        id int(4) not null auto_increment,
	table_border char(15),
	table_header_bg char(15),
	table_cell_bg char(15),
	table_cell_bg_alt char(15),
	table_expand_width    char(15),
	table_collapse_width  char(15),
        main_header_bgcolor char(15),
	body_bgcolor          char(15),
	body_background          char(255),
	owl_logo          char(255),
	body_textcolor        char(15),
	body_link             char(15),
	body_vlink            char(15),
        primary key (id)
);

INSERT INTO html VALUES (1,'0','#B9C1CB','#EDF0F3','#D5DBE3','90%','50%','#B9C1CB','#B9C1CB','/xxx/intranet/graphics/bg.jpg','owl.gif','#000000','#000000','#000000');

CREATE TABLE prefs (
        id int(4) not null auto_increment,
	email_from char(80),
	email_fromname char(80),
	email_replyto    char(80),
	email_server  char(30),
	email_subject  char(60),
        lookathd char(15),
        lookathddel int(4),
	def_file_security          int(4),
	def_file_group_owner        int(4),
	def_file_owner        int(4),
	def_file_title             char(40),
	def_file_meta            char(40),
        def_fold_security	int(4),
	def_fold_group_owner	int(4),
	def_fold_owner		int(4),
	max_filesize		int(4),
	tmpdir		char(255),
	timeout			int(4),
	expand			int(4),
	version_control		int(4),
	restrict_view		int(4),
	hide_backup		int(4),
        dbdump_path             char(80),
        gzip_path               char(80),
        tar_path               char(80),
        unzip_path               char(80),
        pod2html_path               char(80),
        pdftotext_path               char(80),
	file_perm		int(4),
	folder_perm		int(4),
	logging			int(4),
	log_file		int(4),
	log_login               int(4),
	log_rec_per_page	int(4),
	rec_per_page	 	int(4),
	self_reg                int(4),
        self_reg_quota          int(4),
        self_reg_notify         int(4),
        self_reg_attachfile     int(4),
        self_reg_disabled       int(4),
        self_reg_noprefacces    int(4),
        self_reg_maxsessions    int(4),
        self_reg_group          int(4),
	anon_ro		int(4),
	anon_user int(4),
	file_admin_group  int(4),
        forgot_pass int(4),
        collect_trash  int(4),
        trash_can_location char(80),
    	allow_popup int(4),
        status_bar_location int(4),
        hide_bulk int(4),
        use_smtp int(4),
        use_smtp_auth int(4),
        smtp_passwd char(40),
        primary key (id)
);

INSERT INTO prefs (email_from, email_fromname,email_replyto,email_server, lookathd, lookathddel, def_file_security, def_file_group_owner, def_file_owner, def_file_title, def_file_meta, def_fold_security, def_fold_group_owner, def_fold_owner,max_filesize, timeout, expand, version_control, restrict_view, dbdump_path, gzip_path, tar_path, unzip_path, pod2html_path, pdftotext_path, file_perm, folder_perm, anon_ro, hide_backup, logging, log_file, log_login, log_rec_per_page, self_reg, self_reg_quota, self_reg_notify, self_reg_attachfile, self_reg_disabled, self_reg_noprefacces, self_reg_maxsessions, self_reg_group, forgot_pass, email_subject, tmpdir, anon_user, file_admin_group, collect_trash, trash_can_location, allow_popup, status_bar_location, hide_bulk, use_smtp, use_smtp_auth,smtp_passwd, rec_per_page) values ('owl@yourdomain.com','OWL Intranet','noreply@yourdomain.com','localhost', 'false', '1', '0', '0', '1', '<font color=red>No Info</font>', 'not in db', '50', '0', '1', '5120000', '900','1','1','0', '/usr/bin/mysqldump', '/bin/gzip', '/bin/tar', '/usr/bin/unzip', '/usr/local/bin/pod2html', '/usr/bin/pdftotext', '4', '54','1', '0', '0','1','1','5','0','0','0','0','0','0','0','1','0','[OWL Intranet]:','','2','','0','','1','1','0','0','0','','0');

CREATE TABLE monitored_file (
        id int(4) not null auto_increment,
        userid int(4) not null,
        fid int(4) not null,
        primary key (id)
);
CREATE TABLE monitored_folder (
        id int(4) not null auto_increment,
        userid int(4) not null,
        fid int(4) not null,
        primary key (id)
);

CREATE TABLE mimes (
	filetype char(10) not null primary key,
	mimetype char(50) not null
);

--
-- Table structure for table 'wordidx'
--
CREATE TABLE wordidx (
  wordid int(4) default NULL,
  word char(128) NOT NULL default '',
  UNIQUE KEY word_index (word)
) TYPE=MyISAM;

--
-- Table structure for table 'searchidx'
--

CREATE TABLE searchidx (
  wordid int(4) default NULL,
  owlfileid int(4) default NULL,
  KEY search_fileid (owlfileid)
) TYPE=MyISAM;

INSERT INTO groups VALUES (0, 'Administrators');
UPDATE groups SET id = 0 WHERE name = 'Administrators';
INSERT INTO groups VALUES (1, 'Anonymous');
INSERT INTO groups VALUES (2, 'File Admin');
INSERT INTO folders VALUES (0, 'Documents', 0, '', 51, 0, 0);
INSERT INTO users (id,groupid,username,name,password,quota_max,quota_current,notify,attachfile,disabled,noprefaccess,maxsessions,lastlogin,curlogin,newsadmin, comment_notify, buttonstyle) VALUES (0, 0, 'admin', 'Administrator', 'admin', '0', '0', '0','0','0', '0', '0', now(), now(), '0', '0', 'Blue');
INSERT INTO users (id,groupid,username,name,password,quota_max,quota_current,notify,attachfile,disabled,noprefaccess,maxsessions,lastlogin,curlogin,newsadmin, comment_notify, buttonstyle) VALUES (0, 1, 'guest', 'Anonymous', 'guest', '0', '0', '0', '0','1', '1', '19', now(), now(), '0', '0', 'Blue');
INSERT INTO files VALUES (0, 'Test File', 'test.txt', '36', '1', '1', '2000-12-27 05:17:00','', '', '0', '0','2000-12-27 05:17:00', '0', '0', '1','0');
UPDATE users SET language = 'English';
UPDATE users SET password = '21232f297a57a5a743894a0e4a801fc3' WHERE name = 'Administrator';
UPDATE users SET password = '084e0343a0486ff05530df6c705c8bb4' WHERE name = 'Anonymous';


INSERT INTO mimes VALUES ('ai', 'application/postscript');
INSERT INTO mimes VALUES ('aif', 'audio/x-aiff');
INSERT INTO mimes VALUES ('aifc', 'audio/x-aiff');
INSERT INTO mimes VALUES ('aiff', 'audio/x-aiff');
INSERT INTO mimes VALUES ('asc', 'text/plain');
INSERT INTO mimes VALUES ('au', 'audio/basic');
INSERT INTO mimes VALUES ('avi', 'video/x-msvideo');
INSERT INTO mimes VALUES ('bcpio', 'application/x-bcpio');
INSERT INTO mimes VALUES ('bin', 'application/octet-stream');
INSERT INTO mimes VALUES ('bmp', 'image/bmp');
INSERT INTO mimes VALUES ('cdf', 'application/x-netcdf');
INSERT INTO mimes VALUES ('class', 'application/octet-stream');
INSERT INTO mimes VALUES ('cpio', 'application/x-cpio');
INSERT INTO mimes VALUES ('cpt', 'application/mac-compactpro');
INSERT INTO mimes VALUES ('csh', 'application/x-csh');
INSERT INTO mimes VALUES ('css', 'text/css');
INSERT INTO mimes VALUES ('dcr', 'application/x-director');
INSERT INTO mimes VALUES ('dir', 'application/x-director');
INSERT INTO mimes VALUES ('dms', 'application/octet-stream');
INSERT INTO mimes VALUES ('doc', 'application/msword');
INSERT INTO mimes VALUES ('dvi', 'application/x-dvi');
INSERT INTO mimes VALUES ('dxr', 'application/x-director');
INSERT INTO mimes VALUES ('eps', 'application/postscript');
INSERT INTO mimes VALUES ('etx', 'text/x-setext');
INSERT INTO mimes VALUES ('exe', 'application/octet-stream');
INSERT INTO mimes VALUES ('ez', 'application/andrew-inset');
INSERT INTO mimes VALUES ('gif', 'image/gif');
INSERT INTO mimes VALUES ('gtar', 'application/x-gtar');
INSERT INTO mimes VALUES ('hdf', 'application/x-hdf');
INSERT INTO mimes VALUES ('hqx', 'application/mac-binhex40');
INSERT INTO mimes VALUES ('htm', 'text/html');
INSERT INTO mimes VALUES ('html', 'text/html');
INSERT INTO mimes VALUES ('ice', 'x-conference/x-cooltalk');
INSERT INTO mimes VALUES ('ief', 'image/ief');
INSERT INTO mimes VALUES ('iges', 'model/iges');
INSERT INTO mimes VALUES ('igs', 'model/iges');
INSERT INTO mimes VALUES ('jpe', 'image/jpeg');
INSERT INTO mimes VALUES ('jpeg', 'image/jpeg');
INSERT INTO mimes VALUES ('jpg', 'image/jpeg');
INSERT INTO mimes VALUES ('js', 'application/x-javascript');
INSERT INTO mimes VALUES ('kar', 'audio/midi');
INSERT INTO mimes VALUES ('latex', 'application/x-latex');
INSERT INTO mimes VALUES ('lha', 'application/octet-stream');
INSERT INTO mimes VALUES ('lzh', 'application/octet-stream');
INSERT INTO mimes VALUES ('man', 'application/x-troff-man');
INSERT INTO mimes VALUES ('me', 'application/x-troff-me');
INSERT INTO mimes VALUES ('mesh', 'model/mesh');
INSERT INTO mimes VALUES ('mid', 'audio/midi');
INSERT INTO mimes VALUES ('midi', 'audio/midi');
INSERT INTO mimes VALUES ('mif', 'application/vnd.mif');
INSERT INTO mimes VALUES ('mov', 'video/quicktime');
INSERT INTO mimes VALUES ('movie', 'video/x-sgi-movie');
INSERT INTO mimes VALUES ('mp2', 'audio/mpeg');
INSERT INTO mimes VALUES ('mp3', 'audio/mpeg');
INSERT INTO mimes VALUES ('mpe', 'video/mpeg');
INSERT INTO mimes VALUES ('mpeg', 'video/mpeg');
INSERT INTO mimes VALUES ('mpg', 'video/mpeg');
INSERT INTO mimes VALUES ('mpga', 'audio/mpeg');
INSERT INTO mimes VALUES ('ms', 'application/x-troff-ms');
INSERT INTO mimes VALUES ('msh', 'model/mesh');
INSERT INTO mimes VALUES ('nc', 'application/x-netcdf');
INSERT INTO mimes VALUES ('oda', 'application/oda');
INSERT INTO mimes VALUES ('pbm', 'image/x-portable-bitmap');
INSERT INTO mimes VALUES ('pdb', 'chemical/x-pdb');
INSERT INTO mimes VALUES ('pdf', 'application/pdf');
INSERT INTO mimes VALUES ('pgm', 'image/x-portable-graymap');
INSERT INTO mimes VALUES ('pgn', 'application/x-chess-pgn');
INSERT INTO mimes VALUES ('png', 'image/png');
INSERT INTO mimes VALUES ('pnm', 'image/x-portable-anymap');
INSERT INTO mimes VALUES ('ppm', 'image/x-portable-pixmap');
INSERT INTO mimes VALUES ('ppt', 'application/vnd.ms-powerpoint');
INSERT INTO mimes VALUES ('ps', 'application/postscript');
INSERT INTO mimes VALUES ('qt', 'video/quicktime');
INSERT INTO mimes VALUES ('ra', 'audio/x-realaudio');
INSERT INTO mimes VALUES ('ram', 'audio/x-pn-realaudio');
INSERT INTO mimes VALUES ('ras', 'image/x-cmu-raster');
INSERT INTO mimes VALUES ('rgb', 'image/x-rgb');
INSERT INTO mimes VALUES ('rm', 'audio/x-pn-realaudio');
INSERT INTO mimes VALUES ('roff', 'application/x-troff');
INSERT INTO mimes VALUES ('rpm', 'audio/x-pn-realaudio-plugin');
INSERT INTO mimes VALUES ('rtf', 'text/rtf');
INSERT INTO mimes VALUES ('rtx', 'text/richtext');
INSERT INTO mimes VALUES ('sgm', 'text/sgml');
INSERT INTO mimes VALUES ('sgml', 'text/sgml');
INSERT INTO mimes VALUES ('sh', 'application/x-sh');
INSERT INTO mimes VALUES ('shar', 'application/x-shar');
INSERT INTO mimes VALUES ('silo', 'model/mesh');
INSERT INTO mimes VALUES ('sit', 'application/x-stuffit');
INSERT INTO mimes VALUES ('skd', 'application/x-koan');
INSERT INTO mimes VALUES ('skm', 'application/x-koan');
INSERT INTO mimes VALUES ('skp', 'application/x-koan');
INSERT INTO mimes VALUES ('skt', 'application/x-koan');
INSERT INTO mimes VALUES ('smi', 'application/smil');
INSERT INTO mimes VALUES ('smil', 'application/smil');
INSERT INTO mimes VALUES ('snd', 'audio/basic');
INSERT INTO mimes VALUES ('spl', 'application/x-futuresplash');
INSERT INTO mimes VALUES ('src', 'application/x-wais-source');
INSERT INTO mimes VALUES ('sv4cpio', 'application/x-sv4cpio');
INSERT INTO mimes VALUES ('sv4crc', 'application/x-sv4crc');
INSERT INTO mimes VALUES ('swf', 'application/x-shockwave-flash');
INSERT INTO mimes VALUES ('t', 'application/x-troff');
INSERT INTO mimes VALUES ('tar', 'application/x-tar');
INSERT INTO mimes VALUES ('tcl', 'application/x-tcl');
INSERT INTO mimes VALUES ('tex', 'application/x-tex');
INSERT INTO mimes VALUES ('texi', 'application/x-texinfo');
INSERT INTO mimes VALUES ('texinfo', 'application/x-texinfo');
INSERT INTO mimes VALUES ('tif', 'image/tiff');
INSERT INTO mimes VALUES ('tiff', 'image/tiff');
INSERT INTO mimes VALUES ('tr', 'application/x-troff');
INSERT INTO mimes VALUES ('tsv', 'text/tab-separated-values');
INSERT INTO mimes VALUES ('txt', 'text/plain');
INSERT INTO mimes VALUES ('ustar', 'application/x-ustar');
INSERT INTO mimes VALUES ('vcd', 'application/x-cdlink');
INSERT INTO mimes VALUES ('vrml', 'model/vrml');
INSERT INTO mimes VALUES ('wav', 'audio/x-wav');
INSERT INTO mimes VALUES ('wrl', 'model/vrml');
INSERT INTO mimes VALUES ('xbm', 'image/x-xbitmap');
INSERT INTO mimes VALUES ('xls', 'application/vnd.ms-excel');
INSERT INTO mimes VALUES ('xml', 'text/xml');
INSERT INTO mimes VALUES ('xpm', 'image/x-xpixmap');
INSERT INTO mimes VALUES ('xwd', 'image/x-xwindowdump');
INSERT INTO mimes VALUES ('xyz', 'chemical/x-pdb');
INSERT INTO mimes VALUES ('zip', 'application/zip');
INSERT INTO mimes VALUES ('gz', 'application/x-gzip');
INSERT INTO mimes VALUES ('tgz', 'application/x-gzip');

